@@ -266,6 +266,19 @@ void Monitor::init()
     cluster_logger = pcb.create_perf_counters();
   }
 
+  // open compatset
+  {
+    bufferlist bl;
+    store->get_bl_ss(bl, COMPAT_SET_LOC, 0);
+    if (bl.length()) {
+      bufferlist::iterator p = bl.begin();
+      ::decode(features, p);
+    } else {
+      features = get_ceph_mon_feature_compat_set();
+    }
+    dout(10) << "features " << features << dendl;
+  }
+
   // init paxos
   for (int i = 0; i < PAXOS_NUM; ++i) {
     paxos[i]->init();
@@ -387,8 +400,11 @@ void Monitor::bootstrap()
   // note my rank
   int newrank = monmap->get_rank(messenger->get_myaddr());
   if (newrank < 0 && rank >= 0) {
-    dout(0) << " removed from monmap, suicide." << dendl;
-    exit(0);
+    // was i ever part of the quorum?
+    if (store->exists_bl_ss("joined")) {
+      dout(0) << " removed from monmap, suicide." << dendl;
+      exit(0);
+    }
   }
   if (newrank != rank) {
     dout(0) << " my rank is now " << newrank << " (was " << rank << ")" << dendl;
@@ -838,6 +854,9 @@ void Monitor::finish_election()
   resend_routed_requests();
   update_logger();
   register_cluster_logger();
+
+  // make note of the fact that i was, once, part of the quorum.
+  store->put_int(1, "joined");
 } 
 
 
