@@ -13,7 +13,7 @@
 
 #include <sstream>
 
-#define DOUT_SUBSYS rgw
+#define dout_subsys ceph_subsys_rgw
 
 PerfCounters *perfcounter = NULL;
 
@@ -49,193 +49,6 @@ void rgw_perf_stop(CephContext *cct)
   delete perfcounter;
 }
 
-void RGWAccessKey::generate_test_instances(list<RGWAccessKey*>& o)
-{
-  RGWAccessKey *k = new RGWAccessKey;
-  k->id = "id";
-  k->key = "key";
-  k->subuser = "subuser";
-  o.push_back(k);
-  o.push_back(new RGWAccessKey);
-}
-
-void RGWAccessKey::dump(Formatter *f) const
-{
-  f->dump_string("id", id);
-  f->dump_string("key", key);
-  f->dump_string("subuser", subuser);
-}
-
-void RGWSubUser::generate_test_instances(list<RGWSubUser*>& o)
-{
-  RGWSubUser *u = new RGWSubUser;
-  u->name = "name";
-  u->perm_mask = 0xf;
-  o.push_back(u);
-  o.push_back(new RGWSubUser);
-}
-
-void RGWSubUser::dump(Formatter *f) const
-{
-  f->dump_string("name", name);
-  f->dump_unsigned("perm_mask", perm_mask);
-}
-
-void RGWUserInfo::generate_test_instances(list<RGWUserInfo*>& o)
-{
-  RGWUserInfo *i = new RGWUserInfo;
-  i->auid = 1;
-  i->user_id = "user_id";
-  i->display_name =  "display_name";
-  i->user_email = "user@email";
-  RGWAccessKey k1, k2;
-  k1.id = "id1";
-  k1.key = "key1";
-  k2.id = "id2";
-  k2.subuser = "subuser";
-  RGWSubUser u;
-  u.name = "id2";
-  u.perm_mask = 0x1;
-  i->access_keys[k1.id] = k1;
-  i->swift_keys[k2.id] = k2;
-  i->subusers[u.name] = u;
-  o.push_back(i);
-
-  o.push_back(new RGWUserInfo);
-}
-
-void RGWUserInfo::dump(Formatter *f) const
-{
-  f->dump_unsigned("auid", auid);
-  f->dump_string("user_id", user_id);
-  f->dump_string("display_name", display_name);
-  f->dump_string("user_email", user_email);
-
-  map<string, RGWAccessKey>::const_iterator aiter = access_keys.begin();
-  f->open_array_section("access_keys");
-  for (; aiter != access_keys.end(); ++aiter) {
-    f->open_object_section("entry");
-    f->dump_string("uid", aiter->first);
-    f->open_object_section("access_key");
-    aiter->second.dump(f);
-    f->close_section();
-    f->close_section();
-  }
-
-  aiter = swift_keys.begin();
-  for (; aiter != swift_keys.end(); ++aiter) {
-    f->open_object_section("entry");
-    f->dump_string("subuser", aiter->first);
-    f->open_object_section("key");
-    aiter->second.dump(f);
-    f->close_section();
-    f->close_section();
-  }
-  map<string, RGWSubUser>::const_iterator siter = subusers.begin();
-  for (; siter != subusers.end(); ++siter) {
-    f->open_object_section("entry");
-    f->dump_string("id", siter->first);
-    f->open_object_section("subuser");
-    siter->second.dump(f);
-    f->close_section();
-    f->close_section();
-  }
-  f->dump_int("suspended", (int)suspended);
-}
-
-void rgw_bucket::generate_test_instances(list<rgw_bucket*>& o)
-{
-  rgw_bucket *b = new rgw_bucket("name", "pool", "marker", "123");
-  o.push_back(b);
-  o.push_back(new rgw_bucket);
-}
-
-void rgw_bucket::dump(Formatter *f) const
-{
-  f->dump_string("name", name);
-  f->dump_string("pool", pool);
-  f->dump_string("marker", marker);
-  f->dump_string("bucket_id", bucket_id);
-}
-
-void RGWBucketInfo::generate_test_instances(list<RGWBucketInfo*>& o)
-{
-  RGWBucketInfo *i = new RGWBucketInfo;
-  i->bucket = rgw_bucket("bucket", "pool", "marker", "10");
-  i->owner = "owner";
-  i->flags = BUCKET_SUSPENDED;
-  o.push_back(i);
-  o.push_back(new RGWBucketInfo);
-}
-
-void RGWBucketInfo::dump(Formatter *f) const
-{
-  f->open_object_section("bucket");
-  bucket.dump(f);
-  f->close_section();
-  f->dump_string("owner", owner);
-  f->dump_unsigned("flags", flags);
-}
-
-void RGWBucketEnt::generate_test_instances(list<RGWBucketEnt*>& o)
-{
-  RGWBucketEnt *e = new RGWBucketEnt;
-  e->bucket = rgw_bucket("bucket", "pool", "marker", "10");
-  e->size = 1024;
-  e->size_rounded = 4096;
-  e->count = 1;
-  o.push_back(e);
-  o.push_back(new RGWBucketEnt);
-}
-
-void RGWBucketEnt::dump(Formatter *f) const
-{
-  f->open_object_section("bucket");
-  bucket.dump(f);
-  f->close_section();
-  f->dump_unsigned("size", size);
-  f->dump_unsigned("size_rounded", size_rounded);
-  f->dump_stream("mtime") << mtime;
-  f->dump_unsigned("count", count);
-}
-
-void RGWUploadPartInfo::generate_test_instances(list<RGWUploadPartInfo*>& o)
-{
-  RGWUploadPartInfo *i = new RGWUploadPartInfo;
-  i->num = 1;
-  i->size = 10 * 1024 * 1024;
-  i->etag = "etag";
-  o.push_back(i);
-  o.push_back(new RGWUploadPartInfo);
-}
-
-void RGWUploadPartInfo::dump(Formatter *f) const
-{
-  f->dump_unsigned("num", num);
-  f->dump_unsigned("size", size);
-  f->dump_string("etag", etag);
-  f->dump_stream("modified") << modified;
-}
-
-void rgw_obj::generate_test_instances(list<rgw_obj*>& o)
-{
-  rgw_bucket b = rgw_bucket("bucket", "pool", "marker", "10");
-  rgw_obj *obj = new rgw_obj(b, "object");
-  o.push_back(obj);
-  o.push_back(new rgw_obj);
-}
-
-void rgw_obj::dump(Formatter *f) const
-{
-  f->open_object_section("bucket");
-  bucket.dump(f);
-  f->close_section();
-  f->dump_string("key", key);
-  f->dump_string("ns", ns);
-  f->dump_string("object", object);
-}
-
-
 using namespace ceph::crypto;
 
 rgw_err::
