@@ -45,6 +45,8 @@ extern "C" {
 #include <histedit.h>
 }
 
+#define dout_subsys ceph_subsys_
+
 // TODO: should move these into CephToolCtx for consistency
 static enum ceph_tool_mode_t
   ceph_tool_mode(CEPH_TOOL_MODE_CLI_INPUT);
@@ -650,7 +652,7 @@ CephToolCtx* ceph_tool_common_init(ceph_tool_mode_t mode, bool concise)
   tok = tok_init(NULL);
 
   // start up network
-  messenger = new SimpleMessenger(g_ceph_context, entity_name_t::CLIENT(),
+  messenger = new SimpleMessenger(g_ceph_context, entity_name_t::CLIENT(), "client",
                                   getpid());
   messenger->start();
   ctx->dispatcher = new Admin(ctx.get());
